pub struct ConfirmOrganizationInviteLinkRequestModel {
pub organization_id: Uuid,
pub code: Uuid,
pub org_user_key: String,
pub reset_password_key: Option<String>,
pub default_user_collection_name: String,
}Fields
organization_id: Uuidcode: Uuidorg_user_key: StringThe organization symmetric key encrypted to the user.
reset_password_key: Option<String>The user’s account recovery key, supplied when the organization enforces automatic enrollment.
default_user_collection_name: StringThe encrypted name of the default collection created when Organization Data Ownership applies.
Implementations